"""async function logMovies() {
  const response = await fetch("http://example.com/movies.json");
  const movies = await response.json();
  console.log(movies);
}"""


class fetch:
    def __init__(self):
        pass

    def get(self, url):
        pass

    def post(self, url):
        pass

    def put(self, url):
        pass

    def patch(self, url):
        pass

    def delete(self, url):
        pass

